==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/persistenceassociations/impl/SatisfactionInComponentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.persistenceassociations.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.SatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.SatisfactionSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.SatisfactionInComponent;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.SatisfactionInComponentSet;

import java.util.Arrays;
import java.util.List;


public class SatisfactionInComponentSetImpl extends InstanceSet<SatisfactionInComponentSet,SatisfactionInComponent> implements SatisfactionInComponentSet {

    // attributes
    @Override
    public void setComponent_Id( UniqueId ref_Component_Id ) throws XtumlException {
        for ( SatisfactionInComponent satisfactionincomponent : this ) satisfactionincomponent.setComponent_Id( ref_Component_Id );
    }
    @Override
    public void setSatisfaction_Id( UniqueId ref_Satisfaction_Id ) throws XtumlException {
        for ( SatisfactionInComponent satisfactionincomponent : this ) satisfactionincomponent.setSatisfaction_Id( ref_Satisfaction_Id );
    }


    // selections
    @Override
    public C_CSet R9000_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( SatisfactionInComponent satisfactionincomponent : this ) c_cset.add( satisfactionincomponent.R9000_C_C() );
        return c_cset;
    }
    @Override
    public SatisfactionSet R9000_Satisfaction() throws XtumlException {
        SatisfactionSet satisfactionset = new SatisfactionSetImpl();
        for ( SatisfactionInComponent satisfactionincomponent : this ) satisfactionset.add( satisfactionincomponent.R9000_Satisfaction() );
        return satisfactionset;
    }


    @Override
    public SatisfactionInComponent nullElement() {
        return SatisfactionInComponentImpl.EMPTY_SATISFACTIONINCOMPONENT;
    }

    @Override
    public SatisfactionInComponentSet emptySet() {
      return new SatisfactionInComponentSetImpl();
    }

    @Override
    public SatisfactionInComponentSet value() {
        return this;
    }

    @Override
    public List<SatisfactionInComponent> elements() {
        return Arrays.asList(toArray(new SatisfactionInComponent[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/persistenceassociations/impl/SatisfactionInComponentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.persistenceassociations.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.SatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.SatisfactionSetImpl;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.SatisfactionInComponent;
import io.ciera.tool.sql.ooaofooa.persistenceassociations.SatisfactionInComponentSet;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SatisfactionInComponentSetImpl extends InstanceSet<SatisfactionInComponentSet,SatisfactionInComponent> implements SatisfactionInComponentSet {

    public SatisfactionInComponentSetImpl() {
    }

    public SatisfactionInComponentSetImpl(Comparator<? super SatisfactionInComponent> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSatisfaction_Id( UniqueId ref_Satisfaction_Id ) throws XtumlException {
        for ( SatisfactionInComponent satisfactionincomponent : this ) satisfactionincomponent.setSatisfaction_Id( ref_Satisfaction_Id );
    }
    @Override
    public void setComponent_Id( UniqueId ref_Component_Id ) throws XtumlException {
        for ( SatisfactionInComponent satisfactionincomponent : this ) satisfactionincomponent.setComponent_Id( ref_Component_Id );
    }


    // selections
    @Override
    public C_CSet R9000_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( SatisfactionInComponent satisfactionincomponent : this ) c_cset.add( satisfactionincomponent.R9000_C_C() );
        return c_cset;
    }
    @Override
    public SatisfactionSet R9000_Satisfaction() throws XtumlException {
        SatisfactionSet satisfactionset = new SatisfactionSetImpl();
        for ( SatisfactionInComponent satisfactionincomponent : this ) satisfactionset.add( satisfactionincomponent.R9000_Satisfaction() );
        return satisfactionset;
    }


    @Override
    public SatisfactionInComponent nullElement() {
        return SatisfactionInComponentImpl.EMPTY_SATISFACTIONINCOMPONENT;
    }

    @Override
    public SatisfactionInComponentSet emptySet() {
      return new SatisfactionInComponentSetImpl();
    }

    @Override
    public SatisfactionInComponentSet emptySet(Comparator<? super SatisfactionInComponent> comp) {
      return new SatisfactionInComponentSetImpl(comp);
    }

    @Override
    public SatisfactionInComponentSet value() {
        return this;
    }

    @Override
    public List<SatisfactionInComponent> elements() {
        return Arrays.asList(toArray(new SatisfactionInComponent[0]));
    }

}
